@@ -24,10 +24,10 @@
 
 /*
   This is an almost empty thing. The only substantial thing this class
-  handles, is scaling up and down to real-world dimensions (internally
+  handles is scaling up and down to real-world dimensions (internally
   dimensions are against global staff-space.)
-  
  */
+
 Paper_def::Paper_def ()
 {
 }
@@ -72,6 +72,7 @@ Paper_def::get_paper_outputter (String outname)  const
 {
   progress_indication (_f ("paper output to `%s'...",
 			   outname == "-" ? String ("<stdout>") : outname));
+  progress_indication("\n");
 
   global_input_file->target_strings_.push (outname);
   Paper_outputter * po = new Paper_outputter (outname);
