@@ -189,15 +189,19 @@
      . (
 	(breakable . #t)
 	(stacking-dir . 1)
-	(break-align-orders . #((instrument-name left-edge ambitus breathing-sign
-						 clef key-signature staff-bar
+	(break-align-orders . #(; end-of-line:
+				(instrument-name left-edge ambitus breathing-sign
+						 clef  staff-bar key-signature
 						 time-signature custos)
+
+				; unbroken
 				(instrument-name left-edge ambitus breathing-sign
 						 clef  staff-bar key-signature
 						 staff
 						 time-signature custos)
+				; begin of line
 				(instrument-name left-edge ambitus breathing-sign
-						 clef  staff-bar key-signature
+						 clef key-signature staff-bar
 						 time-signature custos)
 
 				))
@@ -389,7 +393,6 @@
 	(script-priority . 100)
 	(font-encoding . number)
 	(font-size . -5) 		; don't overlap when next to heads.
-	(font-shape . upright)
 	(meta . ((interfaces . (finger-interface font-interface text-script-interface text-interface side-position-interface self-alignment-interface item-interface ))))
 	))
 
