@@ -391,6 +391,23 @@ def to_eps (file):
 	ly.system ('dvips -Ppdf -u+lilypond.map -E -o %s.eps %s' \
 		   % (file, file))
 
+
+	# check if it really is EPS.
+	# Otherwise music glyphs disappear from 2nd and following pages.
+
+	# TODO: should run dvips -pp -E per page, then we get proper
+	# cropping as well.
+	
+	f = open ('%s.eps' % file)
+	for x in range(0,10) :
+		if re.search ("^%%Pages: ", f.readline ()):
+
+			# make non EPS.
+			ly.system ('dvips -Ppdf -u+lilypond.map -o %s.eps %s' \
+				   % (file, file))
+			break
+	
+
 def find_file (name):
 	for i in include_path:
 		full = os.path.join (i, name)
@@ -718,18 +735,14 @@ def filter_pipe (input, cmd):
 def run_filter (s):
 	return filter_pipe (s, filter_cmd)
 
-def is_derived (object, base):
-	def recurse (cl,  baseclass):
-		if cl == baseclass:
-			return True
-		for b in cl.__bases__:
-			if recurse (b, baseclass):
-				return True
-		return False
-			
-	cl = object.__class__
-	return recurse (cl, base)
-	
+def is_derived_class (cl,  baseclass):
+	if cl == baseclass:
+		return 1
+	for b in cl.__bases__:
+		if is_derived_class (b, baseclass):
+			return 1
+	return 0
+
 
 def process_snippets (cmd, snippets):
 	names = filter (lambda x: x, map (Lilypond_snippet.basename, snippets))
@@ -891,7 +904,7 @@ def do_file (input_filename):
 		
 		
 	elif process_cmd:
-		outdated = filter (lambda x: is_derived (x, Lilypond_snippet) \
+		outdated = filter (lambda x: is_derived_class (x.__class__, Lilypond_snippet) \
 				   and x.is_outdated (), chunks)
 		ly.progress (_ ("Writing snippets..."))
 		map (Lilypond_snippet.write_ly, outdated)
@@ -917,7 +930,7 @@ def do_file (input_filename):
 		do_file (name)
 		
 	map (process_include,
-	     filter (lambda x: is_derived (x, Include_snippet), chunks))
+	     filter (lambda x: is_derived_class (x.__class__, Include_snippet), chunks))
 
 def do_options ():
 	global format, output_name
